# Youtube Autonomous Advanced Image AI-related extension Module

The image module, in the advanced version, with functionality related to AI.

Please, check the 'pyproject.toml' file to see the dependencies.